ExpandableSliderController class

A controller for an ExpandableSlider.

This class lets you expand or shrink the expandable slider.

Constructors

ExpandableSliderController()
Creates an object that controls the animations of an ExpandableSlider.

Properties

hashCode int
The hash code for this object.
no setterinherited
isExpanded bool
Returns true if the ExpandableSlider is expanded, and false otherwise.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

expand() → void
Starts running the expansion animation forwards.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shrink() → void
Starts running the shrinkage animation forwards.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited